--- Assemble.c
+++ Assemble.c	2003/03/03 11:07:38
@@ -208,21 +208,21 @@
 			continue;
 		}
 		if (ident->super_minor >= 0 &&
-		    (!havesuper || ident->super_minor != super.md_minor)) {
+		    (!havesuper || (unsigned)ident->super_minor != super.md_minor)) {
 			if (inargv || verbose)
 				fprintf(stderr, Name ": %s has wrong super-minor.\n",
 					devname);
 			continue;
 		}
 		if (ident->level != -10 &&
-		    (!havesuper|| ident->level != super.level)) {
+		    (!havesuper|| (unsigned)ident->level != super.level)) {
 			if (inargv || verbose)
 				fprintf(stderr, Name ": %s has wrong raid level.\n",
 					devname);
 			continue;
 		}
 		if (ident->raid_disks != -1 &&
-		    (!havesuper || ident->raid_disks!= super.raid_disks)) {
+		    (!havesuper || (unsigned)ident->raid_disks!= super.raid_disks)) {
 			if (inargv || verbose)
 				fprintf(stderr, Name ": %s requires wrong number of drives.\n",
 					devname);
@@ -258,7 +258,7 @@
 		devices[devcnt].events = md_event(&super);
 		devices[devcnt].utime = super.utime;
 
-		if (super.level == -4) {
+		if ((int)super.level == -4) {
 			/* Workaround: In a multipath setup, all superblocks
 			 * are identical (obviously); so they would all be
 			 * assigned the same slot. */
@@ -302,7 +302,7 @@
 		if (devices[j].events+event_margin >=
 		    devices[most_recent].events) {
 			devices[j].uptodate = 1;
-			if (i < first_super.raid_disks)
+			if ((unsigned)i < first_super.raid_disks)
 				okcnt++;
 			else
 				sparecnt++;
@@ -315,7 +315,7 @@
 		 */
 		int fd;
 		chosen_drive = -1;
-		for (i=0; i<first_super.raid_disks; i++) {
+		for (i=0; (unsigned)i<first_super.raid_disks; i++) {
 			int j = best[i];
 			if (j>=0 &&
 			    !devices[j].uptodate &&
@@ -393,7 +393,7 @@
 		int j = best[i];
 		int desired_state;
 
-		if (i < super.raid_disks)
+		if ((unsigned)i < super.raid_disks)
 			desired_state = (1<<MD_DISK_ACTIVE) | (1<<MD_DISK_SYNC);
 		else
 			desired_state = 0;
@@ -411,14 +411,14 @@
 			super.disks[i].minor = devices[j].minor;
 		}
 #endif 
-		if (devices[j].oldmajor != super.disks[i].major ||
-		    devices[j].oldminor != super.disks[i].minor) {
+		if ((unsigned)devices[j].oldmajor != super.disks[i].major ||
+		    (unsigned)devices[j].oldminor != super.disks[i].minor) {
 			change |= 2;
 			super.disks[i].major = devices[j].oldmajor;
 			super.disks[i].minor = devices[j].oldminor;
 		}
 		if (devices[j].uptodate &&
-		    (super.disks[i].state != desired_state)) {
+		    (super.disks[i].state != (unsigned)desired_state)) {
 			if (force) {
 				fprintf(stderr, Name ": "
 					"clearing FAULTY flag for device %d in %s for %s\n",
@@ -485,21 +485,21 @@
 						devices[j].devname,
 						mddev,
 						strerror(errno));
-					if (i < first_super.raid_disks)
+					if ((unsigned)i < first_super.raid_disks)
 						okcnt--;
 					else
 						sparecnt--;
 				} else if (verbose)
 					fprintf(stderr, Name ": added %s to %s as %d\n",
 						devices[j].devname, mddev, devices[j].raid_disk);
-			} else if (verbose && i < first_super.raid_disks)
+			} else if (verbose && (unsigned)i < first_super.raid_disks)
 				fprintf(stderr, Name ": no uptodate device for slot %d of %s\n",
 					i, mddev);
 		}
 		
 		if (runstop == 1 ||
 		    (runstop == 0 && 
-		     ( first_super.raid_disks == okcnt
+		     ( first_super.raid_disks == (unsigned)okcnt
 		       || (start_partial_ok && enough(first_super.level, first_super.raid_disks, okcnt)))
 			    )) {
 			if (ioctl(mdfd, RUN_ARRAY, NULL)==0) {
--- Assemble.c
+++ Assemble.c	2003/03/03 11:07:38
@@ -326,7 +326,7 @@
 			    > devices[most_recent].events)
 				most_recent = devcnt;
 		}
-		if (super.level == -4) 
+		if ((int)super.level == -4) 
 			/* with multipath, the raid_disk from the superblock is meaningless */
 			i = devcnt;
 		else
@@ -356,7 +356,7 @@
 		/* note: we ignore error flags in multipath arrays
 		 * as they don't make sense
 		 */
-		if (first_super.level != -4)
+		if ((int)first_super.level != -4)
 			if (!(devices[j].state & (1<<MD_DISK_SYNC)))
 				continue;
 		if (devices[j].events+event_margin >=
@@ -502,7 +502,7 @@
 		}
 	}
 	if (force && (super.level == 4 || super.level == 5) && 
-	    okcnt == super.raid_disks-1) {
+	    okcnt == (int)super.raid_disks-1) {
 		super.state = (1<< MD_SB_CLEAN);
 		change |= 2;
 	}
--- Create.c
+++ Create.c	2002/12/02 10:18:32
@@ -162,7 +162,7 @@
 		freesize = MD_NEW_SIZE_SECTORS(dsize);
 		freesize /= 2;
 
-		if (size && freesize < size) {
+		if (size && freesize < (unsigned long)size) {
 			fprintf(stderr, Name ": %s is smaller that given size."
 				" %ldK < %dK + superblock\n", dname, freesize, size);
 			fail = 1;
--- Detail.c
+++ Detail.c	2002/12/02 10:19:23
@@ -171,8 +171,8 @@
 				int fd = open(dv, O_RDONLY);
 				if (fd >=0 &&
 				    load_super(fd, &super) ==0 &&
-				    super.ctime == array.ctime &&
-				    super.level == array.level)
+				    super.ctime == (unsigned)array.ctime &&
+				    super.level == (unsigned)array.level)
 					have_super = 1;
 			}
 		}
--- Examine.c
+++ Examine.c	2002/12/02 10:19:56
@@ -158,7 +158,7 @@
 			printf("Working Devices : %d\n", super.working_disks);
 			printf(" Failed Devices : %d\n", super.failed_disks);
 			printf("  Spare Devices : %d\n", super.spare_disks);
-			if (calc_sb_csum(&super) == super.sb_csum)
+			if ((unsigned)calc_sb_csum(&super) == super.sb_csum)
 				printf("       Checksum : %x - correct\n", super.sb_csum);
 			else
 				printf("       Checksum : %x - expected %x\n", super.sb_csum, calc_sb_csum(&super));
--- Monitor.c
+++ Monitor.c	2003/03/03 11:02:41
@@ -262,7 +262,7 @@
 				if (ioctl(fd, GET_DISK_INFO, &disc)>= 0) {
 					newstate = disc.state;
 					dv = map_dev(disc.major, disc.minor);
-				} else if (mse &&  mse->pattern && i < strlen(mse->pattern))
+				} else if (mse &&  mse->pattern && (unsigned)i < strlen(mse->pattern))
 					switch(mse->pattern[i]) {
 					case 'U': newstate = 6 /* ACTIVE/SYNC */; break;
 					case '_': newstate = 0; break;
--- Query.c
+++ Query.c	2002/12/02 10:22:05
@@ -129,7 +129,7 @@
 			if (md_get_version(fd) >= 9000 &&	
 			    ioctl(fd, GET_ARRAY_INFO, &array)>= 0) {
 				if (ioctl(fd, GET_DISK_INFO, &disc) >= 0 &&
-				    MKDEV(disc.major,disc.minor) == stb.st_rdev)
+				    (unsigned)MKDEV(disc.major,disc.minor) == stb.st_rdev)
 					activity = "active";
 				else
 					activity = "mismatch";
--- config.c
+++ config.c	2002/12/02 10:06:46
@@ -407,7 +407,7 @@
 	struct conf_dev *cd;
 	int flags = 0;
 	static mddev_dev_t dlist = NULL;
-	int i;
+	unsigned i;
 
 	while (dlist) {
 		mddev_dev_t t = dlist;
